@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.016-7-g1d7c6e6
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.017-5-gd9c33d7
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -249,7 +249,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -390,7 +390,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kent Fredric Mohammad S Anwar
+=for stopwords Kent Fredric Klaus Eichner Mohammad S Anwar
 
 =over 4
 
@@ -400,6 +400,10 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
+Klaus Eichner <klaus03@gmail.com>
+
+=item *
+
 Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =back
